==> ogre-13.1.1-1-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/group___g_l_s_lang_program_manager.js <==
var group___g_l_s_lang_program_manager =
[
    [ "Ogre::GLSLangPlugin", "class_ogre_1_1_g_l_s_lang_plugin.html", [
      [ "getName", "class_ogre_1_1_g_l_s_lang_plugin.html#af1cc80b1d641a78b10b87a9f5f5c8c03", null ],
      [ "install", "class_ogre_1_1_g_l_s_lang_plugin.html#a9323b9030d22d533a0970d0b73bccf98", null ],
      [ "initialise", "class_ogre_1_1_g_l_s_lang_plugin.html#a269c5ec0aaf8cd7aa6e1a8e472facc46", null ],
      [ "shutdown", "class_ogre_1_1_g_l_s_lang_plugin.html#ae5b0cb634f2a752b86b6dba1aa160a2a", null ],
      [ "uninstall", "class_ogre_1_1_g_l_s_lang_plugin.html#a9d74a9bcc4e87a8cdc77a6e6cdbfd25f", null ]
    ] ],
    [ "Ogre::GLSLangProgram", "class_ogre_1_1_g_l_s_lang_program.html", [
      [ "GLSLangProgram", "class_ogre_1_1_g_l_s_lang_program.html#a19921cd4985f579daf5a31767e790611", null ],
      [ "getLanguage", "class_ogre_1_1_g_l_s_lang_program.html#ac29d6b4db0dd7c6153d2ba569dd5cc5f", null ],
      [ "isSupported", "class_ogre_1_1_g_l_s_lang_program.html#a822b2bfd7bdf7b6efc9aa82263ee4ce1", null ]
    ] ],
    [ "Ogre::GLSLangProgramFactory", "class_ogre_1_1_g_l_s_lang_program_factory.html", [
      [ "GLSLangProgramFactory", "class_ogre_1_1_g_l_s_lang_program_factory.html#a6392de053cf0f5c9551ca1f603a40cde", null ],
      [ "~GLSLangProgramFactory", "class_ogre_1_1_g_l_s_lang_program_factory.html#a441759472b6f5bcee294da22889b2c25", null ],
      [ "getLanguage", "class_ogre_1_1_g_l_s_lang_program_factory.html#a74688686f5bef686455752198123e371", null ],
      [ "create", "class_ogre_1_1_g_l_s_lang_program_factory.html#a3f7cb0e6890007a4ac3d0b9298c533dd", null ]
    ] ]
];

==> ogre-13.4.4-1-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/group___g_l_s_lang_program_manager.js <==
var group___g_l_s_lang_program_manager =
[
    [ "Ogre::GLSLangPlugin", "class_ogre_1_1_g_l_s_lang_plugin.html", [
      [ "getName", "class_ogre_1_1_g_l_s_lang_plugin.html#af1cc80b1d641a78b10b87a9f5f5c8c03", null ],
      [ "install", "class_ogre_1_1_g_l_s_lang_plugin.html#a9323b9030d22d533a0970d0b73bccf98", null ],
      [ "initialise", "class_ogre_1_1_g_l_s_lang_plugin.html#a269c5ec0aaf8cd7aa6e1a8e472facc46", null ],
      [ "shutdown", "class_ogre_1_1_g_l_s_lang_plugin.html#ae5b0cb634f2a752b86b6dba1aa160a2a", null ],
      [ "uninstall", "class_ogre_1_1_g_l_s_lang_plugin.html#a9d74a9bcc4e87a8cdc77a6e6cdbfd25f", null ]
    ] ],
    [ "Ogre::GLSLangProgram", "class_ogre_1_1_g_l_s_lang_program.html", [
      [ "GLSLangProgram", "class_ogre_1_1_g_l_s_lang_program.html#a19921cd4985f579daf5a31767e790611", null ],
      [ "~GLSLangProgram", "class_ogre_1_1_g_l_s_lang_program.html#a90f104a6b7cb0aef7366d37783f7e63b", null ],
      [ "getLanguage", "class_ogre_1_1_g_l_s_lang_program.html#ac29d6b4db0dd7c6153d2ba569dd5cc5f", null ],
      [ "isSupported", "class_ogre_1_1_g_l_s_lang_program.html#a822b2bfd7bdf7b6efc9aa82263ee4ce1", null ]
    ] ],
    [ "Ogre::GLSLangProgramFactory", "class_ogre_1_1_g_l_s_lang_program_factory.html", [
      [ "GLSLangProgramFactory", "class_ogre_1_1_g_l_s_lang_program_factory.html#a6392de053cf0f5c9551ca1f603a40cde", null ],
      [ "~GLSLangProgramFactory", "class_ogre_1_1_g_l_s_lang_program_factory.html#a441759472b6f5bcee294da22889b2c25", null ],
      [ "getLanguage", "class_ogre_1_1_g_l_s_lang_program_factory.html#a74688686f5bef686455752198123e371", null ],
      [ "create", "class_ogre_1_1_g_l_s_lang_program_factory.html#a3f7cb0e6890007a4ac3d0b9298c533dd", null ]
    ] ]
];
